@@ -25,18 +25,19 @@ import java.io.BufferedWriter;
 import java.io.File;
 import java.io.FileWriter;
 import java.io.IOException;
+
 import org.apache.tools.ant.BuildException;
 import org.apache.tools.ant.Location;
 import org.apache.tools.ant.Project;
 import org.apache.tools.ant.taskdefs.Execute;
 import org.apache.tools.ant.taskdefs.Javac;
 import org.apache.tools.ant.taskdefs.LogStreamHandler;
+import org.apache.tools.ant.taskdefs.condition.Os;
 import org.apache.tools.ant.types.Commandline;
 import org.apache.tools.ant.types.Path;
 import org.apache.tools.ant.util.FileUtils;
-import org.apache.tools.ant.util.StringUtils;
 import org.apache.tools.ant.util.JavaEnvUtils;
-import org.apache.tools.ant.taskdefs.condition.Os;
+import org.apache.tools.ant.util.StringUtils;
 
 /**
  * This is the default implementation for the CompilerAdapter interface.
@@ -96,7 +97,7 @@ public abstract class DefaultCompilerAdapter
      *
      * @param attributes a configured Javac task.
      */
-    public void setJavac(Javac attributes) {
+    public void setJavac(final Javac attributes) {
         this.attributes = attributes;
         src = attributes.getSrcdir();
         destDir = attributes.getDestdir();
@@ -135,7 +136,7 @@ public abstract class DefaultCompilerAdapter
      * of files.
      */
     public String[] getSupportedFileExtensions() {
-        return new String[] { "java" };
+        return new String[] {"java"};
     }
 
     /**
@@ -152,7 +153,7 @@ public abstract class DefaultCompilerAdapter
      * @return the compilation class path
      */
     protected Path getCompileClasspath() {
-        Path classpath = new Path(project);
+        final Path classpath = new Path(project);
 
         // add dest dir to classpath so that previously compiled and
         // untouched classes are on classpath
@@ -186,7 +187,7 @@ public abstract class DefaultCompilerAdapter
      * @param cmd the command line
      * @return the command line
      */
-    protected Commandline setupJavacCommandlineSwitches(Commandline cmd) {
+    protected Commandline setupJavacCommandlineSwitches(final Commandline cmd) {
         return setupJavacCommandlineSwitches(cmd, false);
     }
 
@@ -197,9 +198,9 @@ public abstract class DefaultCompilerAdapter
      * @param useDebugLevel if true set set the debug level with the -g switch
      * @return the command line
      */
-    protected Commandline setupJavacCommandlineSwitches(Commandline cmd,
-                                                        boolean useDebugLevel) {
-        Path classpath = getCompileClasspath();
+    protected Commandline setupJavacCommandlineSwitches(final Commandline cmd,
+                                                        final boolean useDebugLevel) {
+        final Path classpath = getCompileClasspath();
         // For -sourcepath, use the "sourcepath" value if present.
         // Otherwise default to the "srcdir" value.
         Path sourcepath = null;
@@ -209,7 +210,7 @@ public abstract class DefaultCompilerAdapter
             sourcepath = src;
         }
 
-        String memoryParameterPrefix = assumeJava11() ? "-J-" : "-J-X";
+        final String memoryParameterPrefix = assumeJava11() ? "-J-" : "-J-X";
         if (memoryInitialSize != null) {
             if (!attributes.isForkedJavac()) {
                 attributes.log("Since fork is false, ignoring "
@@ -250,9 +251,9 @@ public abstract class DefaultCompilerAdapter
         // Just add "sourcepath" to classpath ( for JDK1.1 )
         // as well as "bootclasspath" and "extdirs"
         if (assumeJava11()) {
-            Path cp = new Path(project);
+            final Path cp = new Path(project);
 
-            Path bp = getBootClassPath();
+            final Path bp = getBootClassPath();
             if (bp.size() > 0) {
                 cp.append(bp);
             }
@@ -276,7 +277,7 @@ public abstract class DefaultCompilerAdapter
                 cmd.createArgument().setValue(target);
             }
 
-            Path bp = getBootClassPath();
+            final Path bp = getBootClassPath();
             if (bp.size() > 0) {
                 cmd.createArgument().setValue("-bootclasspath");
                 cmd.createArgument().setPath(bp);
@@ -294,7 +295,7 @@ public abstract class DefaultCompilerAdapter
         }
         if (debug) {
             if (useDebugLevel && !assumeJava11()) {
-                String debugLevel = attributes.getDebugLevel();
+                final String debugLevel = attributes.getDebugLevel();
                 if (debugLevel != null) {
                     cmd.createArgument().setValue("-g:" + debugLevel);
                 } else {
@@ -336,7 +337,7 @@ public abstract class DefaultCompilerAdapter
      * @param cmd the command line
      * @return the command line
      */
-    protected Commandline setupModernJavacCommandlineSwitches(Commandline cmd) {
+    protected Commandline setupModernJavacCommandlineSwitches(final Commandline cmd) {
         setupJavacCommandlineSwitches(cmd, true);
         if (!assumeJava13()) { // -source added with JDK 1.4
             final String t = attributes.getTarget();
@@ -358,7 +359,7 @@ public abstract class DefaultCompilerAdapter
      * @return the command line
      */
     protected Commandline setupModernJavacCommand() {
-        Commandline cmd = new Commandline();
+        final Commandline cmd = new Commandline();
         setupModernJavacCommandlineSwitches(cmd);
 
         logAndAddFilesToCompile(cmd);
@@ -379,8 +380,8 @@ public abstract class DefaultCompilerAdapter
      * @param debugLevelCheck if true set the debug level with the -g switch
      * @return the command line
      */
-    protected Commandline setupJavacCommand(boolean debugLevelCheck) {
-        Commandline cmd = new Commandline();
+    protected Commandline setupJavacCommand(final boolean debugLevelCheck) {
+        final Commandline cmd = new Commandline();
         setupJavacCommandlineSwitches(cmd, debugLevelCheck);
         logAndAddFilesToCompile(cmd);
         return cmd;
@@ -391,11 +392,11 @@ public abstract class DefaultCompilerAdapter
      * &quot;niceSourceList&quot;
      * @param cmd the command line
      */
-    protected void logAndAddFilesToCompile(Commandline cmd) {
+    protected void logAndAddFilesToCompile(final Commandline cmd) {
         attributes.log("Compilation " + cmd.describeArguments(),
                        Project.MSG_VERBOSE);
 
-        StringBuffer niceSourceList = new StringBuffer("File");
+        final StringBuffer niceSourceList = new StringBuffer("File");
         if (compileList.length != 1) {
             niceSourceList.append("s");
         }
@@ -404,7 +405,7 @@ public abstract class DefaultCompilerAdapter
         niceSourceList.append(StringUtils.LINE_SEP);
 
         for (int i = 0; i < compileList.length; i++) {
-            String arg = compileList[i].getAbsolutePath();
+            final String arg = compileList[i].getAbsolutePath();
             cmd.createArgument().setValue(arg);
             niceSourceList.append("    ");
             niceSourceList.append(arg);
@@ -423,7 +424,7 @@ public abstract class DefaultCompilerAdapter
      * system.
      * @return the exit code of the compilation
      */
-    protected int executeExternalCompile(String[] args, int firstFileName) {
+    protected int executeExternalCompile(final String[] args, final int firstFileName) {
         return executeExternalCompile(args, firstFileName, true);
     }
 
@@ -446,8 +447,8 @@ public abstract class DefaultCompilerAdapter
      *
      * @since Ant 1.6
      */
-    protected int executeExternalCompile(String[] args, int firstFileName,
-                                         boolean quoteFiles) {
+    protected int executeExternalCompile(final String[] args, final int firstFileName,
+                                         final boolean quoteFiles) {
         String[] commandArray = null;
         File tmpFile = null;
 
@@ -479,7 +480,7 @@ public abstract class DefaultCompilerAdapter
                     commandArray = new String[firstFileName + 1];
                     System.arraycopy(args, 0, commandArray, 0, firstFileName);
                     commandArray[firstFileName] = "@" + tmpFile;
-                } catch (IOException e) {
+                } catch (final IOException e) {
                     throw new BuildException("Error creating temporary file",
                                              e, location);
                 } finally {
@@ -490,7 +491,7 @@ public abstract class DefaultCompilerAdapter
             }
 
             try {
-                Execute exe = new Execute(
+                final Execute exe = new Execute(
                                   new LogStreamHandler(attributes,
                                                        Project.MSG_INFO,
                                                        Project.MSG_WARN));
@@ -504,7 +505,7 @@ public abstract class DefaultCompilerAdapter
                 exe.setCommandline(commandArray);
                 exe.execute();
                 return exe.getExitValue();
-            } catch (IOException e) {
+            } catch (final IOException e) {
                 throw new BuildException("Error running " + args[0]
                         + " compiler", e, location);
             }
@@ -521,7 +522,8 @@ public abstract class DefaultCompilerAdapter
      * @deprecated since 1.5.x.
      *             Use org.apache.tools.ant.types.Path#addExtdirs instead.
      */
-    protected void addExtdirsToClasspath(Path classpath) {
+    @Deprecated
+    protected void addExtdirsToClasspath(final Path classpath) {
         classpath.addExtdirs(extdirs);
     }
 
@@ -529,7 +531,7 @@ public abstract class DefaultCompilerAdapter
      * Adds the command line arguments specific to the current implementation.
      * @param cmd the command line to use
      */
-    protected void addCurrentCompilerArgs(Commandline cmd) {
+    protected void addCurrentCompilerArgs(final Commandline cmd) {
         cmd.addArguments(getJavac().getCurrentCompilerArgs());
     }
 
@@ -605,11 +607,20 @@ public abstract class DefaultCompilerAdapter
         return assumeJavaXY("javac1.8", JavaEnvUtils.JAVA_1_8);
     }
 
+    /**
+     * Shall we assume JDK 1.9 command line switches?
+     * @return true if JDK 1.9
+     * @since Ant 1.9.4
+     */
+    protected boolean assumeJava19() {
+        return assumeJavaXY("javac1.9", JavaEnvUtils.JAVA_1_9);
+    }
+
     /**
      * Shall we assume command line switches for the given version of Java?
      * @since Ant 1.8.3
      */
-    private boolean assumeJavaXY(String javacXY, String javaEnvVersionXY) {
+    private boolean assumeJavaXY(final String javacXY, final String javaEnvVersionXY) {
         return javacXY.equals(attributes.getCompilerVersion())
             || ("classic".equals(attributes.getCompilerVersion())
                 && JavaEnvUtils.isJavaVersion(javaEnvVersionXY))
@@ -627,7 +638,7 @@ public abstract class DefaultCompilerAdapter
      * specified and the system bootclasspath.
      */
     protected Path getBootClassPath() {
-        Path bp = new Path(project);
+        final Path bp = new Path(project);
         if (bootclasspath != null) {
             bp.append(bootclasspath);
         }
@@ -648,8 +659,8 @@ public abstract class DefaultCompilerAdapter
         return assumeJava11() ? null : "-g:none";
     }
 
-    private void setImplicitSourceSwitch(Commandline cmd,
-                                         String target, String source) {
+    private void setImplicitSourceSwitch(final Commandline cmd,
+                                         final String target, final String source) {
         attributes.log("", Project.MSG_WARN);
         attributes.log("          WARNING", Project.MSG_WARN);
         attributes.log("", Project.MSG_WARN);
@@ -680,6 +691,9 @@ public abstract class DefaultCompilerAdapter
         if (assumeJava18()) {
             return "1.8 in JDK 1.8";
         }
+        if (assumeJava19()) {
+            return "1.9 in JDK 1.9";
+        }
         return "";
     }
 
@@ -702,7 +716,9 @@ public abstract class DefaultCompilerAdapter
         return t.equals("1") || t.equals("2") || t.equals("3") || t.equals("4")
             || ((t.equals("5") || t.equals("6"))
                 && !assumeJava15() && !assumeJava16())
-            || (t.equals("7") && !assumeJava17());
+            || (t.equals("7") && !assumeJava17())
+            || (t.equals("8") && !assumeJava18())
+            || (t.equals("9") && !assumeJava19());
     }
 
 
@@ -713,7 +729,7 @@ public abstract class DefaultCompilerAdapter
      * <p>support for -source 1.1 and -source 1.2 has been added with
      * JDK 1.4.2 but isn't present in 1.5.0+</p>
      */
-    private String adjustSourceValue(String source) {
+    private String adjustSourceValue(final String source) {
         return (source.equals("1.1") || source.equals("1.2")) ? "1.3" : source;
     }
 }
