@@ -155,11 +155,9 @@ public class DefaultCompilerAdapterTest {
         testSource("1.7", "javac1.9",
                    "If you specify -target 1.7 you now must also specify"
                    + " -source 1.7", "1.7");
-        //TODO: This is the behaviour I would expect from analogy. But at the moment
-        // (jdk-1.9.0_b06) this is not 'implemented'.
-//        testSource("1.8", "javac1.9",
-//                "If you specify -target 1.8 you now must also specify"
-//                + " -source 1.8", "1.8");
+        testSource("1.8", "javac1.9",
+                   "If you specify -target 1.8 you now must also specify"
+                   + " -source 1.8", "1.8");
         testSource("5", "javac1.9",
                    "If you specify -target 5 you now must also specify"
                    + " -source 5", "5");
@@ -169,13 +167,11 @@ public class DefaultCompilerAdapterTest {
         testSource("7", "javac1.9",
                    "If you specify -target 7 you now must also specify"
                    + " -source 7", "7");
-        //TODO: This is the behaviour I would expect from analogy. But at the moment
-        // (jdk-1.9.0_b06) this is not 'implemented'.
-//        testSource("8", "javac1.9",
-//                "If you specify -target 8 you now must also specify"
-//                + " -source 8", "8");
-        testSource(null, "javac1.9", "", "1.8");
-        testSource(null, "javac1.9", "", "8");
+        testSource("8", "javac1.9",
+                   "If you specify -target 8 you now must also specify"
+                   + " -source 8", "8");
+        testSource(null, "javac1.9", "", "1.9");
+        testSource(null, "javac1.9", "", "9");
     }
 
     private void commonSourceDowngrades(String javaVersion) {
